@@ -1,7 +1,7 @@
 package IPC::System::Options;
 
 our $DATE = '2015-07-27'; # DATE
-our $VERSION = '0.19'; # VERSION
+our $VERSION = '0.20'; # VERSION
 
 use strict;
 use warnings;
@@ -169,12 +169,23 @@ sub _system_or_backtick {
     }
 
     if ($exit_code) {
-        $log->errorf("%s(%s) failed: %d (%s)",
-                     $which, \@args, $exit_code,
-                     explain_child_error($exit_code, $os_error))
-            if $opts->{log};
-        croak "$which(".join(" ", @args).") failed: " .
-            explain_child_error($exit_code, $os_error) if $opt_die;
+        if ($opts->{log} || $opt_die) {
+            my $msg = sprintf(
+                "%s(%s) failed: %d (%s)%s%s",
+                $which,
+                join(" ", @args),
+                $exit_code,
+                explain_child_error($exit_code, $os_error),
+                (ref($opts->{capture_stdout}) ?
+                     ", captured stdout: <<" .
+                     ${$opts->{capture_stdout}} . ">>" : ""),
+                (ref($opts->{capture_stderr}) ?
+                     ", captured stderr: <<" .
+                     ${$opts->{capture_stderr}} . ">>" : ""),
+            );
+            $log->error($msg) if $opts->{log};
+            croak $msg if $opt_die;
+        }
     }
 
     # make sure our user see the correct exit code & os error. this is not
@@ -209,7 +220,7 @@ IPC::System::Options - Perl's system() and backtick/qx replacement/wrapper, with
 
 =head1 VERSION
 
-This document describes version 0.19 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-07-27.
+This document describes version 0.20 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-07-27.
 
 =head1 SYNOPSIS
 
